<template>
  <el-dialog
    width="60%"
    title="选择样品零件"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :paramObj="paramObj"
      :bottomOffset="250"
      :ajaxFun="ajaxFun"
      ref="commonApplyPartTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`saveSelectRow`"
        >确 定</el-button
      >
    </div>
  </el-dialog>
</template>
<script>
import { fetchListApplyPart } from '@/api/quality/apply'
import { addReportSample } from '@/api/quality/report'
import ttable from '@/views/common/ztt-table'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    reportId: {
      type: Number,
      default: 0
    }
  },
  data() {
    return {
      paramObj: { reportId: 0 },
      ajaxFun: fetchListApplyPart,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        isGeneralSearch: true,
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'systemNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '160',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '160',
            prop: 'lotBatchNo',
            label: '零件批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '160',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '160',
            prop: 'partDesc',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '160',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'testStandardNo',
            label: '检测标准编号（计划）',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      },
      isSubmit: false
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      this.isSubmit = true
      if (
        this.reportId &&
        this.multipleSelection &&
        this.multipleSelection.length > 0
      ) {
        const samplePartList = new Array()
        this.multipleSelection.forEach((item, index, array) => {
          samplePartList.push(
            Object.assign({
              reportId: this.reportId,
              systemNo: item.systemNo,
              testStandardNo: item.testStandardNo,
              testStandardId: item.moTestStandardId,
              isMoTestStandard: true
            })
          )
        })
        addReportSample(samplePartList).then((response) => {
          this.$emit('handleSelectionChange')
          this.innerVisible = false
          this.isSubmit = false
          this.$message.success('添加样品成功')
        })
      } else {
        this.isSubmit = false
      }
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      if (this.$refs.commonApplyPartTable !== undefined) {
        this.$refs.commonApplyPartTable.getDataList()
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    },
    reportId() {
      this.paramObj = { reportId: this.reportId }
    }
  }
}
</script>
<style>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
